@@ -1,5 +1,5 @@
 /* Find and resolve or report look-ahead conflicts for bison,
-   Copyright 2000 Free Software Foundation, Inc.
+   Copyright (C) 2000, 2001, 2002, 2004 Free Software Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
@@ -22,13 +22,13 @@
 # define CONFLICTS_H_
 # include "state.h"
 
-void initialize_conflicts PARAMS ((void));
-void print_conflicts PARAMS ((void));
-void print_reductions PARAMS ((int));
-void finalize_conflicts PARAMS ((void));
+void conflicts_solve (void);
+void conflicts_print (void);
+int conflicts_total_count (void);
+void conflicts_output (FILE *out);
+void conflicts_free (void);
 
 /* Were there conflicts? */
-extern int any_conflicts;
-extern errs **err_table;
-extern int expected_conflicts;
+extern int expected_sr_conflicts;
+extern int expected_rr_conflicts;
 #endif /* !CONFLICTS_H_ */
