@@ -1,5 +1,5 @@
 /* Parse command line arguments for bison.
-   Copyright 1984, 1986, 1989, 1992, 2000, 2001, 2002
+   Copyright (C) 1984, 1986, 1989, 1992, 2000, 2001, 2002, 2003, 2004
    Free Software Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
@@ -26,42 +26,62 @@
 extern const char *skeleton;		/* for -S */
 extern const char *include;		/* for -I */
 
-extern int debug_flag; 		/* for -t */
-extern int defines_flag;    	/* for -d */
-extern int locations_flag;
-extern int no_lines_flag;    	/* for -l */
-extern int no_parser_flag;	/* for -n */
-extern int token_table_flag;   	/* for -k */
-extern int graph_flag;		/* for -g */
-extern int yacc_flag;  		/* for -y */
+extern bool debug_flag;			/* for -t */
+extern bool defines_flag;		/* for -d */
+extern bool locations_flag;
+extern bool no_lines_flag;		/* for -l */
+extern bool no_parser_flag;		/* for -n */
+extern bool token_table_flag;		/* for -k */
+extern bool graph_flag;			/* for -g */
+extern bool yacc_flag;			/* for -y */
+
+/* GLR_PARSER is true if the input file says to use the GLR
+   (Generalized LR) parser, and to output some additional information
+   used by the GLR algorithm.  */
+
+extern bool glr_parser;
+
+/* PURE_PARSER is true if should generate a parser that is all pure
+   and reentrant.  */
+
+extern bool pure_parser;
+
+/* NONDETERMINISTIC_PARSER is true iff conflicts are accepted.  This
+   is used by the GLR parser, and might be used in BackTracking
+   parsers too.  */
+
+extern bool nondeterministic_parser;
 
 /* --trace.  */
-enum trace_e
+enum trace
   {
     trace_none      = 0,
-    trace_resource  = 1 << 0,
-    trace_sets      = 1 << 1,
-    trace_bitsets   = 1 << 2,
-    trace_tools     = 1 << 3,
-    trace_automaton = 1 << 4,
-    trace_grammar   = 1 << 5,
-    trace_time      = 1 << 6,
+    trace_scan      = 1 << 0,
+    trace_parse     = 1 << 1,
+    trace_resource  = 1 << 2,
+    trace_sets      = 1 << 3,
+    trace_bitsets   = 1 << 4,
+    trace_tools     = 1 << 5,
+    trace_automaton = 1 << 6,
+    trace_grammar   = 1 << 7,
+    trace_time      = 1 << 8,
+    trace_skeleton  = 1 << 9,
     trace_all       = ~0
   };
 extern int trace_flag;
 
 /* --report.  */
-enum report_e
+enum report
   {
     report_none             = 0,
     report_states           = 1 << 0,
     report_itemsets         = 1 << 1,
-    report_lookaheads       = 1 << 2,
+    report_look_ahead_tokens= 1 << 2,
     report_solved_conflicts = 1 << 3,
     report_all              = ~0
   };
 extern int report_flag;
 
-void getargs PARAMS ((int argc, char *argv[]));
+void getargs (int argc, char *argv[]);
 
 #endif /* !GETARGS_H_ */
