@@ -1,7 +1,7 @@
-/* A Bison parser, made by GNU Bison 1.875a.  */
+/* A Bison parser, made by GNU Bison 2.0b.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.  */
 
 /* As a special exception, when this file is copied by Bison into a
    Bison output file, you may use that output file without restriction.
@@ -45,34 +45,39 @@
      PERCENT_DPREC = 270,
      PERCENT_MERGE = 271,
      PERCENT_DEBUG = 272,
-     PERCENT_DEFINE = 273,
-     PERCENT_DEFINES = 274,
-     PERCENT_ERROR_VERBOSE = 275,
-     PERCENT_EXPECT = 276,
-     PERCENT_FILE_PREFIX = 277,
-     PERCENT_GLR_PARSER = 278,
-     PERCENT_LEX_PARAM = 279,
-     PERCENT_LOCATIONS = 280,
-     PERCENT_NAME_PREFIX = 281,
-     PERCENT_NO_LINES = 282,
-     PERCENT_OUTPUT = 283,
-     PERCENT_PARSE_PARAM = 284,
-     PERCENT_PURE_PARSER = 285,
-     PERCENT_SKELETON = 286,
-     PERCENT_START = 287,
-     PERCENT_TOKEN_TABLE = 288,
-     PERCENT_VERBOSE = 289,
-     PERCENT_YACC = 290,
-     TYPE = 291,
-     EQUAL = 292,
-     SEMICOLON = 293,
-     PIPE = 294,
-     ID = 295,
-     ID_COLON = 296,
-     PERCENT_PERCENT = 297,
-     PROLOGUE = 298,
-     EPILOGUE = 299,
-     BRACED_CODE = 300
+     PERCENT_DEFAULT_PREC = 273,
+     PERCENT_DEFINE = 274,
+     PERCENT_DEFINES = 275,
+     PERCENT_ERROR_VERBOSE = 276,
+     PERCENT_EXPECT = 277,
+     PERCENT_EXPECT_RR = 278,
+     PERCENT_FILE_PREFIX = 279,
+     PERCENT_GLR_PARSER = 280,
+     PERCENT_INITIAL_ACTION = 281,
+     PERCENT_LEX_PARAM = 282,
+     PERCENT_LOCATIONS = 283,
+     PERCENT_NAME_PREFIX = 284,
+     PERCENT_NO_DEFAULT_PREC = 285,
+     PERCENT_NO_LINES = 286,
+     PERCENT_NONDETERMINISTIC_PARSER = 287,
+     PERCENT_OUTPUT = 288,
+     PERCENT_PARSE_PARAM = 289,
+     PERCENT_PURE_PARSER = 290,
+     PERCENT_SKELETON = 291,
+     PERCENT_START = 292,
+     PERCENT_TOKEN_TABLE = 293,
+     PERCENT_VERBOSE = 294,
+     PERCENT_YACC = 295,
+     TYPE = 296,
+     EQUAL = 297,
+     SEMICOLON = 298,
+     PIPE = 299,
+     ID = 300,
+     ID_COLON = 301,
+     PERCENT_PERCENT = 302,
+     PROLOGUE = 303,
+     EPILOGUE = 304,
+     BRACED_CODE = 305
    };
 #endif
 #define GRAM_EOF 0
@@ -91,40 +96,45 @@
 #define PERCENT_DPREC 270
 #define PERCENT_MERGE 271
 #define PERCENT_DEBUG 272
-#define PERCENT_DEFINE 273
-#define PERCENT_DEFINES 274
-#define PERCENT_ERROR_VERBOSE 275
-#define PERCENT_EXPECT 276
-#define PERCENT_FILE_PREFIX 277
-#define PERCENT_GLR_PARSER 278
-#define PERCENT_LEX_PARAM 279
-#define PERCENT_LOCATIONS 280
-#define PERCENT_NAME_PREFIX 281
-#define PERCENT_NO_LINES 282
-#define PERCENT_OUTPUT 283
-#define PERCENT_PARSE_PARAM 284
-#define PERCENT_PURE_PARSER 285
-#define PERCENT_SKELETON 286
-#define PERCENT_START 287
-#define PERCENT_TOKEN_TABLE 288
-#define PERCENT_VERBOSE 289
-#define PERCENT_YACC 290
-#define TYPE 291
-#define EQUAL 292
-#define SEMICOLON 293
-#define PIPE 294
-#define ID 295
-#define ID_COLON 296
-#define PERCENT_PERCENT 297
-#define PROLOGUE 298
-#define EPILOGUE 299
-#define BRACED_CODE 300
+#define PERCENT_DEFAULT_PREC 273
+#define PERCENT_DEFINE 274
+#define PERCENT_DEFINES 275
+#define PERCENT_ERROR_VERBOSE 276
+#define PERCENT_EXPECT 277
+#define PERCENT_EXPECT_RR 278
+#define PERCENT_FILE_PREFIX 279
+#define PERCENT_GLR_PARSER 280
+#define PERCENT_INITIAL_ACTION 281
+#define PERCENT_LEX_PARAM 282
+#define PERCENT_LOCATIONS 283
+#define PERCENT_NAME_PREFIX 284
+#define PERCENT_NO_DEFAULT_PREC 285
+#define PERCENT_NO_LINES 286
+#define PERCENT_NONDETERMINISTIC_PARSER 287
+#define PERCENT_OUTPUT 288
+#define PERCENT_PARSE_PARAM 289
+#define PERCENT_PURE_PARSER 290
+#define PERCENT_SKELETON 291
+#define PERCENT_START 292
+#define PERCENT_TOKEN_TABLE 293
+#define PERCENT_VERBOSE 294
+#define PERCENT_YACC 295
+#define TYPE 296
+#define EQUAL 297
+#define SEMICOLON 298
+#define PIPE 299
+#define ID 300
+#define ID_COLON 301
+#define PERCENT_PERCENT 302
+#define PROLOGUE 303
+#define EPILOGUE 304
+#define BRACED_CODE 305
 
 
 
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 74 "parse-gram.y"
+#line 79 "parse-gram.y"
 typedef union YYSTYPE {
   symbol *symbol;
   symbol_list *list;
@@ -133,8 +143,8 @@ typedef union YYSTYPE {
   assoc assoc;
   uniqstr uniqstr;
 } YYSTYPE;
-/* Line 1240 of yacc.c.  */
-#line 138 "y.tab.h"
+/* Line 1447 of yacc.c.  */
+#line 148 "parse-gram.h"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
