@@ -1,6 +1,6 @@
 /* Input parser for Bison
 
-   Copyright (C) 2000, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
@@ -16,8 +16,8 @@
 
    You should have received a copy of the GNU General Public License
    along with Bison; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.  */
 
 #ifndef READER_H_
 # define READER_H_
@@ -38,6 +38,7 @@ typedef struct merger_list
 extern FILE *gram_in;
 extern int gram__flex_debug;
 extern boundary scanner_cursor;
+extern int max_left_semantic_context;
 void scanner_initialize (void);
 void scanner_free (void);
 void scanner_last_string_free (void);
@@ -53,10 +54,9 @@ char const *token_name (int);
 
 
 /* From reader.c. */
-void grammar_start_symbol_set (symbol *s, location loc);
+void grammar_start_symbol_set (symbol *sym, location loc);
 void prologue_augment (const char *prologue, location loc);
-void epilogue_augment (const char *epilogue, location loc);
-void grammar_symbol_append (symbol *s, location loc);
+void grammar_symbol_append (symbol *sym, location loc);
 void grammar_rule_begin (symbol *lhs, location loc);
 void grammar_rule_end (location loc);
 void grammar_midrule_action (void);
@@ -72,6 +72,7 @@ void free_merger_functions (void);
 
 extern merger_list *merge_functions;
 
-extern int typed;
+extern bool typed;
+extern bool default_prec;
 
 #endif /* !READER_H_ */
